/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *
 *   Copyright (C) 2001-2006  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 *********************************************************************/

#include "constants.h"

#include "card_played.h"

#include "../../misc/translations.h"

#include "../../utils/string.h"

/**
 ** constructor
 **
 ** @param	playerno	player who has played the card
 ** @param	card		played card
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::CardPlayed::CardPlayed(unsigned const playerno,
					 Card const& card) :
  GameplayAction(CARD_PLAYED, playerno),
  card(card)
{
} // CardPlayed::CardPlayed()

/**
 ** constructor
 **
 ** @param	line	line with the data
 **
 ** @return	action corresponding to the line
 **		(to be freed)
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 ** 
 ** @todo	new format
 **/
GameplayAction::CardPlayed::CardPlayed(string line) :
  GameplayAction(CARD_PLAYED, UINT_MAX),
  card()
{
#ifndef OUTDATED
  // old format in the bug report:
  //   Played: Player 2: club ace
  if (string(line, 0, strlen("Played: ")) == "Played: ") {
    // the first word is 'Played'
    DK::Utils::String::word_first_remove_with_blanks(line);
    // the next word is 'player', remove it also
    DK::Utils::String::word_first_remove_with_blanks(line);
    // next comes the player number, followed by a ':'
    this->player = static_cast<unsigned>(atoi(line.c_str()));
    // remove the player number
    DK::Utils::String::word_first_remove_with_blanks(line);

    // the last part is the card
    this->card = Card(line);

    return ;
  }
#endif

  // ToDo: new format

} // GameplayAction::CardPlayed(string line)

/**
 ** copy constructor
 **
 ** @param	card_played	action to copy
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::CardPlayed::CardPlayed(CardPlayed const& card_played) :
  GameplayAction(card_played),
  card(card_played.card)
{
} // CardPlayed::CardPlayed(CardPlayed card_played)

/**
 ** copy constructor
 **
 ** @param	card_played	action to copy
 **
 ** @return	this action
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::CardPlayed::CardPlayed&
GameplayAction::CardPlayed::operator=(CardPlayed const& card_played)
{
  this->GameplayAction::operator=(card_played);
  this->card = card_played.card;
  return *this;
} // CardPlayed& CardPlayed::operator=(CardPlayed card_played)

/**
 ** destructor
 **
 ** @param	-
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::CardPlayed::~CardPlayed()
{
} // CardPlayed::~CardPlayed()

/**
 **
 ** writes the action in the output stream
 **
 ** @param	ostr	output stream
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
void
GameplayAction::CardPlayed::write(ostream& ostr) const
{
  ostr << this->type;
  ostr << " = " << this->player;
  ostr << ", " << this->card;

  return ;
} // void write(ostream& ostr) const

/**
 ** -> result
 **
 ** @param	-
 **
 ** @return	a translation representing the data
 ** 
 ** @author	Diether Knof
 **
 ** @version	0.7.1
 **/
Translator::Translation
GameplayAction::CardPlayed::data_translation() const
{
  return ::translation(this->card);
} // virtual Translator::Translation GameplayAction::CardPlayed::data_translation() const
