/**********************************************************************
 *
 *   FreeDoko a Doppelkopf-Game
 *
 *   Copyright (C) 2001-2006  by Diether Knof and Borg Enders
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *   You can find this license in the file 'gpl.txt'.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *   MA  02111-1307  USA
 *
 *  Contact:
 *    Diether Knof dknof@gmx.de
 *    Borg Enders  borg@borgsoft.de
 *
 *********************************************************************/

#include "constants.h"

#include "poverty_returned.h"

#include "../../misc/translations.h"

/**
 ** constructor
 **
 ** @param	playerno	player who has returned the cards
 ** @param	cards		returneded cards
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::PovertyReturned::PovertyReturned(unsigned const playerno,
						 vector<Card> const& cards) :
  GameplayAction(POVERTY_RETURNED, playerno),
  cards(cards)
{
} // PovertyReturned::PovertyReturned(unsigned playerno, vector<Card> cards)

/**
 ** constructor
 **
 ** @param	line	line with the data
 **
 ** @return	action corresponding to the line
 **		(to be freed)
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 ** 
 ** @todo	old format
 ** @todo	new format
 **/
GameplayAction::PovertyReturned::PovertyReturned(string line) :
  GameplayAction(POVERTY_RETURNED, UINT_MAX),
  cards()
{
#ifndef OUTDATED
  // old format in the bug report:
  //   Played: Player 2: club ace
  if (string(line, 0, strlen("")) == "Poverty Returned: ") {
    // ToDo

    return ;
  }
#endif

  // ToDo: new format

} // GameplayAction::PovertyReturned(string line)

/**
 ** copy constructor
 **
 ** @param	poverty_returned	action to copy
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::PovertyReturned::PovertyReturned(PovertyReturned const&
						 poverty_returned) :
  GameplayAction(poverty_returned),
  cards(poverty_returned.cards)
{
} // PovertyReturned::PovertyReturned(PovertyReturned poverty_returned)

/**
 ** copy constructor
 **
 ** @param	poverty_returned	action to copy
 **
 ** @return	this action
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::PovertyReturned::PovertyReturned&
GameplayAction::PovertyReturned::operator=(PovertyReturned const& poverty_returned)
{
  this->GameplayAction::operator=(poverty_returned);
  this->cards = poverty_returned.cards;
  return *this;
} // PovertyReturned& PovertyReturned::operator=(PovertyReturned poverty_returned)

/**
 ** destructor
 **
 ** @param	-
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
GameplayAction::PovertyReturned::~PovertyReturned()
{
} // PovertyReturned::~PovertyReturned()

/**
 **
 ** writes the action in the output stream
 **
 ** @param	ostr	output stream
 **
 ** @return	-
 **
 ** @author	Diether Knof
 ** 
 ** @version	0.7.1
 **/
void
GameplayAction::PovertyReturned::write(ostream& ostr) const
{
  ostr << this->type;
  ostr << " = " << this->player;
  for (vector<Card>::const_iterator c = this->cards.begin();
       c != this->cards.begin();
       ++c)
    ostr << " " << *c;

  return ;
} // void write(ostream& ostr) const

/**
 ** -> result
 **
 ** @param	-
 **
 ** @return	a translation representing the data
 ** 
 ** @author	Diether Knof
 **
 ** @version	0.7.1
 **/
Translator::Translation
GameplayAction::PovertyReturned::data_translation() const
{
  vector<Card>::const_iterator c = this->cards.begin();
  if (c == this->cards.end())
    return ::translation("");

  Translator::Translation translation = ::translation(*c);
  for (++c; c != this->cards.begin(); ++c)
    translation += ", " + ::translation(*c);

  return translation;
} // virtual Translator::Translation GameplayAction::PovertyReturned::data_translation() const
